package #
Date::Manip::Offset::off371;
# Copyright (c) 2008-2017 Sullivan Beck.  All rights reserved.
# This program is free software; you can redistribute it and/or modify it
# under the same terms as Perl itself.

# This file was automatically generated.  Any changes to this file will
# be lost the next time 'tzdata' is run.
#    Generated on: Tue May 30 10:44:03 EDT 2017
#    Data version: tzdata2017b
#    Code version: tzcode2017b

# This module contains data from the zoneinfo time zone database.  The original
# data was obtained from the URL:
#    ftp://ftp.iana.org/tz

use strict;
use warnings;
require 5.010000;

our ($VERSION);
$VERSION='6.60';
END { undef $VERSION; }

our ($Offset,%Offset);
END {
   undef $Offset;
   undef %Offset;
}

$Offset        = '-06:00:00';

%Offset        = (
   0 => [
      'america/chicago',
      'america/indiana/knox',
      'america/indiana/tell_city',
      'america/menominee',
      'america/winnipeg',
      'america/rainy_river',
      'america/belize',
      'america/guatemala',
      'america/costa_rica',
      'america/el_salvador',
      'america/tegucigalpa',
      'america/matamoros',
      'america/merida',
      'america/monterrey',
      'america/bahia_banderas',
      'america/mexico_city',
      'america/managua',
      'america/resolute',
      'america/rankin_inlet',
      'america/regina',
      'america/swift_current',
      'pacific/easter',
      'pacific/galapagos',
      'america/north_dakota/center',
      'america/north_dakota/new_salem',
      'america/north_dakota/beulah',
      'etc/gmt-6',
      'f',
      'america/cancun',
      'america/indiana/petersburg',
      'america/indiana/vincennes',
      'america/indiana/winamac',
      'america/cambridge_bay',
      'america/kentucky/monticello',
      'america/iqaluit',
      'america/pangnirtung',
      'america/chihuahua',
      'america/ojinaga',
      'america/indiana/marengo',
      'america/kentucky/louisville',
      'america/indiana/indianapolis',
      'america/indiana/vevay',
      'america/hermosillo',
      'america/mazatlan',
      'america/atikokan',
      'america/detroit',
      'america/thunder_bay',
      ],
   1 => [
      'america/denver',
      'america/edmonton',
      'america/boise',
      'america/cambridge_bay',
      'america/yellowknife',
      'america/inuvik',
      'america/mazatlan',
      'america/chihuahua',
      'america/ojinaga',
      'america/north_dakota/beulah',
      'america/bahia_banderas',
      'america/north_dakota/new_salem',
      'america/hermosillo',
      'america/north_dakota/center',
      'pacific/easter',
      'america/phoenix',
      'america/swift_current',
      'america/regina',
      ],
);

1;
